==> af-common-websocket-1.1.1-sources.jar: com/af/v4/system/common/websocket/handler/DefaultMessageHandler.java <==
package com.af.v4.system.common.websocket.handler;

import com.af.v4.system.common.logic.service.LogicService;
import com.af.v4.system.plugins.json.JsonTools;
import com.github.linyuzai.connection.loadbalance.core.concept.Connection;
import com.github.linyuzai.connection.loadbalance.core.message.Message;
import com.github.linyuzai.connection.loadbalance.core.message.MessageHandler;
import com.github.linyuzai.connection.loadbalance.websocket.concept.WebSocketConnection;
import org.json.JSONObject;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeansException;
import org.springframework.context.ApplicationContext;
import org.springframework.context.ApplicationContextAware;
import org.springframework.stereotype.Component;

import java.net.URI;
import java.util.Map;

/**
 * 默认websocket消息处理器
 *
 * @author Mr.river
 */
@Component
public class DefaultMessageHandler implements MessageHandler, ApplicationContextAware {
    private static final Logger LOGGER = LoggerFactory.getLogger(DefaultMessageHandler.class);
    private static ApplicationContext applicationContext;

    @Override
    public void onMessage(Message message, Connection connection) {
        WebSocketConnection webSocketConnection = ((WebSocketConnection) connection);
        URI uri = webSocketConnection.getUri();
        String path = uri.getPath();
        String payLoad = message.getPayload();
        Map<String, String> queryParameterMap = webSocketConnection.getQueryParameterMap();
        String logicName = path.substring(path.lastIndexOf("/") + 1);
        JSONObject params;
        if (payLoad != null) {
            params = new JSONObject(payLoad);
        } else {
            params = new JSONObject();
        }
        if (queryParameterMap != null && !queryParameterMap.isEmpty()) {
            JsonTools.addJSON(params, new JSONObject(queryParameterMap));
        }
        applicationContext.getBean(LogicService.class).run(logicName, params);
    }

    @Override
    public void setApplicationContext(ApplicationContext ctx) throws BeansException {
        applicationContext = ctx;
    }
}

==> af-common-websocket-1.1.11.1-sources.jar: com/af/v4/system/common/websocket/handler/DefaultMessageHandler.java <==
package com.af.v4.system.common.websocket.handler;

import com.af.v4.system.common.core.utils.SpringUtils;
import com.af.v4.system.common.logic.service.LogicService;
import com.af.v4.system.common.plugins.json.JsonTools;
import com.github.linyuzai.connection.loadbalance.core.concept.Connection;
import com.github.linyuzai.connection.loadbalance.core.message.Message;
import com.github.linyuzai.connection.loadbalance.core.message.MessageHandler;
import com.github.linyuzai.connection.loadbalance.websocket.concept.WebSocketConnection;
import org.json.JSONObject;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Component;

import java.net.URI;
import java.util.Map;

/**
 * 默认websocket消息处理器
 *
 * @author Mr.river
 */
@Component
public class DefaultMessageHandler implements MessageHandler {
    private static final Logger LOGGER = LoggerFactory.getLogger(DefaultMessageHandler.class);

    @Override
    public void onMessage(Message message, Connection connection) {
        WebSocketConnection webSocketConnection = ((WebSocketConnection) connection);
        URI uri = webSocketConnection.getUri();
        String path = uri.getPath();
        String payLoad = message.getPayload();
        Map<String, String> queryParameterMap = webSocketConnection.getQueryParameterMap();
        String logicName = path.substring(path.lastIndexOf("/") + 1);
        JSONObject params;
        if (payLoad != null) {
            params = new JSONObject(payLoad);
        } else {
            params = new JSONObject();
        }
        if (queryParameterMap != null && !queryParameterMap.isEmpty()) {
            JsonTools.addJSON(params, new JSONObject(queryParameterMap));
        }
        SpringUtils.getBean(LogicService.class).run(logicName, params);
    }
}
